package ru.ulstu.services;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import ru.ulstu.models.Forecast;
import ru.ulstu.models.TimeSeries;
import ru.ulstu.models.TimeSeriesValue;
import ru.ulstu.models.exceptions.TimeSeriesValidateException;
import ru.ulstu.tsMethods.exponential.NoTrendNoSeason;

import java.time.LocalDate;


@Service
public class TimeSeriesService {
    private static final Logger LOGGER = LoggerFactory.getLogger(TimeSeriesService.class);

    public TimeSeries getRandomTimeSeries(int length) {
        TimeSeries ts = new TimeSeries("Random time series");
        LocalDate dateStart = LocalDate.now().minusDays(length);
        for (int i = 0; i < length; i++) {
            ts.getValues().add(new TimeSeriesValue(dateStart, Math.random()));
            dateStart = dateStart.plusDays(1);
        }
        return ts;
    }

    public Forecast getForecast(TimeSeries timeSeries, int countForecast) {
        try {
            NoTrendNoSeason nn = new NoTrendNoSeason(timeSeries);
            nn.setAlpa(0.1);
            nn.createModel();
            return nn.getForecast();
        } catch (TimeSeriesValidateException ex) {
            LOGGER.error("Некорректная инициализация метода моделирования", ex);
            return null;
        }
    }
}
